@@ -26,7 +26,11 @@ class Agent(BaseModel):
 
 
 class AgentCommandResult(BaseModel):
+    command_id: int
+
     status: AgentCommandResultStatus
+    started: datetime
+    stopped: datetime
 
     # output of command, all optional
     return_value: Optional[int] = None
