@@ -77,6 +77,10 @@ async def call_external_command_async(
     debug_log_handler: OutputHandler = NO_OUTPUT,
     error_log_handler: OutputHandler = NO_OUTPUT,
 ) -> int:
+    assert command
+    assert isinstance(command, list)
+    assert all(isinstance(c, str) for c in command)
+
     env = dict(env)
     # await add_log(
     #     perftest_id,
